@@ -2,3 +2,6 @@
 
 mod input;
 pub use self::input::*;
+
+mod rand;
+pub use self::rand::*;
